@@ -92,20 +92,41 @@ except:
    pass
 
 
-# Work-around for the qt4agg backend which does not report resize events.
+# Work-arounds for the qt4agg backend.
 #
 try:
    from matplotlib.backends import backend_qt4agg
 
+#
+#  Enable reporting resize events which the qt4agg normally doesn't do.
+#
    def resizeEvent( self, e ):
       backend_qt4agg.FigureCanvasQT.resizeEvent( self, e )
       self.resize_event()
 
+#
+#  Allow keypress events also when auto-repeating. By default these
+#  are suppressed as of matplotlib version 1.1.0.
+#
+   def _get_key( self, event ):
+###        if event.isAutoRepeat():
+###            return None
+        if event.key() < 256:
+            key = str(event.text())
+        elif event.key() in self.keyvald:
+            key = self.keyvald[ event.key() ]
+        else:
+            key = None
+          
+        return key 
+
+
    backend_qt4agg.FigureCanvasQTAgg.resizeEvent = resizeEvent
+   backend_qt4agg.FigureCanvasQTAgg._get_key = _get_key
 except:
    pass
 
-
+import weakref
    
 # ==========================================================================
 #                             class AxesCallback
@@ -224,10 +245,11 @@ first :class:`AxesCallback` object `draw` as an attribute.
 
    def __init__(self, proc, axes, eventtype, schedule=True, **attr):
       self.proc      = proc
-      self.axes      = axes
+      self.axes      = weakref.proxy(axes)
+      self.axref     = weakref.ref(axes)
       self.eventtype = eventtype
       self.canvas    = axes.get_figure().canvas
-      for name in attr.keys():
+      for name in list(attr.keys()):
          self.__dict__[name] = attr[name]
       self.active    = False
       if schedule:
@@ -241,6 +263,8 @@ first :class:`AxesCallback` object `draw` as an attribute.
       objects so that its callback function will be called before others.
       """
 
+      if self.axref() is None:
+         raise Exception('Axes object does not exist anymore')
       if self.active:
          self.__scheduled.remove(self)        # remove from current position ..
          self.__scheduled.insert(0, self)     # .. and move to front of list
@@ -281,13 +305,16 @@ first :class:`AxesCallback` object `draw` as an attribute.
       def __handler(event):
          if event.canvas.widgetlock.locked(): return
          for callback in AxesCallback.__scheduled:
+            axes = callback.axref()
+            if axes is None:
+               callback.deschedule()
+               continue
             if event.canvas is callback.canvas   and \
                   event.name==callback.eventtype and \
-                  callback.axes.contains(event)[0]:
+                  axes.contains(event)[0]:
                callback.event = event
                callback.xdata, callback.ydata = \
-                  callback.axes.transData.inverted().transform(
-                                                        (event.x, event.y))
+                  axes.transData.inverted().transform((event.x, event.y))
                if callback.proc(callback):
                   break
       return __handler
@@ -360,7 +387,7 @@ there is no position involved.
       self.proc      = proc
       self.canvas    = canvas
       self.eventtype = eventtype
-      for name in attr.keys():
+      for name in list(attr.keys()):
          self.__dict__[name] = attr[name]
       self.active    = False
       if schedule:
@@ -412,7 +439,6 @@ there is no position involved.
 
    def __handler():
       def __handler(event):
-         if event.canvas.widgetlock.locked(): return
          for callback in CanvasCallback.__scheduled:
             if event.canvas is callback.canvas and \
                   event.name==callback.eventtype:
@@ -430,7 +456,7 @@ from os.path import basename
 from numpy import ma
 from matplotlib.colors import Colormap
 from matplotlib import cm
-from tabarray import tabarray
+from kapteyn.tabarray import tabarray
 from kapteyn import package_dir
 
 class VariableColormap(Colormap):
@@ -509,12 +535,13 @@ Values should be between 0.0 and 1.0.
       self.invrt = 1.0
       self.scale = 'LINEAR'
       self.auto  = True
+      self.callback = None
 
    def __call__(self, X, alpha=1.0, bytes=False):
       if self.bad_set:
          if not isinstance(X, numpy.ma.masked_array):
             X = numpy.ma.asarray(X)
-         X.mask = ma.make_mask(-numpy.isfinite(X))
+         X.mask = ma.make_mask(~numpy.isfinite(X))
       return Colormap.__call__(self, X, alpha, bytes)
 
    def __len__(self):
@@ -545,8 +572,8 @@ Values should be between 0.0 and 1.0.
       lut_tail = self.baselut[ncolors:]
       newmap = numpy.zeros((length,3), numpy.float)
       factor = float(ncolors-1)/(length-1)
-      xdest  = numpy.array(range(length), numpy.float)*factor
-      xsrc   = range(ncolors)
+      xdest  = numpy.array(list(range(length)), numpy.float)*factor
+      xsrc   = list(range(ncolors))
       for primary in [0,1,2]:
          primap = numpy.interp(xdest, xsrc, self.baselut[:ncolors,primary])
          newmap[:,primary] = primap
@@ -621,14 +648,14 @@ Values should be between 0.0 and 1.0.
       lut     = self._lut
       worklut = self.worklut
       slope   = slope*self.invrt
-      for i in xrange(ncolors):
+      for i in range(ncolors):
          x = (float(i)/float(ncolors-1))-0.5
          y = slope*(x-shift)+0.5
          if y>1.0:
             y = 1.0
          elif y<0.0:
             y = 0.0
-         m = float(ncolors-1)*y+0.5
+         m = int(float(ncolors-1)*y+0.5)
          lut[i] = worklut[m]
       
       if self.auto:
@@ -653,29 +680,29 @@ Values should be between 0.0 and 1.0.
 
       if scale=='LOG':
          fac = float(ncolors-1)/math.log(ncolors)
-         for i in xrange(ncolors):
-            worklut[i] = baselut[fac*math.log(i+1)]
+         for i in range(ncolors):
+            worklut[i] = baselut[int(fac*math.log(i+1))]
 
       elif scale=='EXP':
          fac = float(ncolors-1)/math.pow(10.0, (ncolors-1)/100.0 -1.0)
-         for i in xrange(ncolors):
-            worklut[i] = baselut[fac*math.pow(10.0, i/100.0-1.0)]
+         for i in range(ncolors):
+            worklut[i] = baselut[int(fac*math.pow(10.0, i/100.0-1.0))]
 
       elif scale=='SQRT':
          fac = float(ncolors-1)/math.sqrt(ncolors)
-         for i in xrange(ncolors):
-            worklut[i] = baselut[fac*math.sqrt(i)]
+         for i in range(ncolors):
+            worklut[i] = baselut[int(fac*math.sqrt(i))]
             
       elif scale=='SQUARE':
          fac = float(ncolors-1)/(ncolors*ncolors)
-         for i in xrange(ncolors):
-            worklut[i] = baselut[fac*i*i]
+         for i in range(ncolors):
+            worklut[i] = baselut[int(fac*i*i)]
 
       elif scale=='LINEAR':
          worklut[:] = baselut[:]
 
       else:
-         raise Exception, 'invalid colormap scale'
+         raise Exception('invalid colormap scale')
       
       self.scale = scale
       self.modify(self.slope, self.shift)
@@ -714,7 +741,8 @@ Values should be between 0.0 and 1.0.
             image.changed()
       for canvas in self.canvases:
          canvas.draw()
-
+      if self.callback is not None:
+         self.callback()
 
 # ==========================================================================
 #                        function KeyPressFilter
@@ -816,14 +844,14 @@ These steps take place at 0.1 second intervals.
    def __new__(cls, *args, **kwds):
       backend = rcParams['backend'].upper()
       if backend in TimeCallback.supported:
-         return object.__new__(TimeCallback.supported[backend], *args, **kwds)
+         return object.__new__(TimeCallback.supported[backend])
       else:
-         raise Exception, 'TimeCallback not supported for backend %s' % backend
+         raise Exception('TimeCallback not supported for backend %s' % backend)
 
    def __init__(self, proc, interval, schedule=True, **attr):
       self.proc     = proc
       self.interval = interval
-      for name in attr.keys():
+      for name in list(attr.keys()):
          self.__dict__[name] = attr[name]
       self.id     = 0
       self.active   = False
@@ -899,7 +927,7 @@ try:
       def __init__(self, proc, interval, schedule=True, **attr):
          self.proc     = proc
          self.interval = interval
-         for name in attr.keys():
+         for name in list(attr.keys()):
             self.__dict__[name] = attr[name]
          self.active   = False
          self.timer = QtCore.QTimer()
@@ -1007,12 +1035,12 @@ Here is an example::
    elif backend in ['QT4AGG']:
       gipsy.qtconnect()
    elif backend in ['TKAGG']:
-      import Tkinter
+      import tkinter
       def _tkio(fd, mask):
          gipsy.hersignal()
       window = get_current_fig_manager().window
       fd = gipsy.herconnect()
-      window.tk.createfilehandler(fd, Tkinter.READABLE, _tkio)
+      window.tk.createfilehandler(fd, tkinter.READABLE, _tkio)
    else:
-      raise RuntimeError, 'Unsupported matplotlib backend for GIPSY connect'
+      raise RuntimeError('Unsupported matplotlib backend for GIPSY connect')
 
